package com.brulijam.minecraftapi.controller;

import com.brulijam.minecraftapi.service.MinecraftQuery;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.json.JSONObject;
import org.springframework.web.bind.annotation.*;

import java.io.IOException;
import java.net.InetSocketAddress;

@RestController
@Tag(name = "Minecraft Server API")
public class MinecraftController {

//    @Operation(summary = "example summary", description = "example description")
//    @GetMapping("/getMeem")
//    public String getMeem() {
//        return "Snens";
//    }
//
//    @PostMapping("/postMeem")
//    public String postMeem(@Parameter(name = "name", description = "name of stuff", example = "srgjbngeir") @RequestParam String name) {
//        return name + "meem";
//    }

    @GetMapping(value = "/getAll", produces = "application/json")
    public String all(@Parameter(name = "host", description = "host of minecraft server", example = "134.255.208.230") String host, @Parameter(name = "port", description = "Server Port", example = "57200") int port) throws IOException {
        MinecraftQuery query = new MinecraftQuery();
        query.setHost(new InetSocketAddress(host, port));
        return query.fetchData();
    }

    @GetMapping(value = "/getGameVersion", produces = "application/json")
    public String getGameVersion(@Parameter(name = "host", description = "host of minecraft server", example = "134.255.208.230") String host, @Parameter(name = "port", description = "Server Port", example = "57200") int port) throws IOException {
        MinecraftQuery query = new MinecraftQuery();
        query.setHost(new InetSocketAddress(host, port));
        String data = query.fetchData();
        JSONObject json = new JSONObject(data);

        return json.getJSONObject("version").toString();
    }

    @GetMapping(value = "/getPlayers", produces = "application/json")
    public String getPlayers(@Parameter(name = "host", description = "host of minecraft server", example = "134.255.208.230") String host, @Parameter(name = "port", description = "Server Port", example = "57200") int port) throws IOException {
        MinecraftQuery query = new MinecraftQuery();
        query.setHost(new InetSocketAddress(host, port));
        String data = query.fetchData();
        JSONObject json = new JSONObject(data);

        return json.getJSONObject("players").toString();
    }

    @GetMapping(value = "/getOnlinePlayers", produces = "application/json")
    public String getOnlinePlayers(@Parameter(name = "host", description = "host of minecraft server", example = "134.255.208.230") String host, @Parameter(name = "port", description = "Server Port", example = "57200") int port) throws IOException {
        MinecraftQuery query = new MinecraftQuery();
        query.setHost(new InetSocketAddress(host, port));
        String data = query.fetchData();
        JSONObject json = new JSONObject(data);

        String onlinePlayers;
        try {
            onlinePlayers = json.getJSONObject("players").getJSONArray("sample").toString();
        } catch(Exception e) {
            onlinePlayers = "no players online";
        }


        return onlinePlayers;
    }


    @GetMapping(value = "/getFavicon", produces = "application/json")
    public String getFavicon(@Parameter(name = "host", description = "host of minecraft server", example = "134.255.208.230") String host, @Parameter(name = "port", description = "Server Port", example = "57200") int port) throws IOException {
        MinecraftQuery query = new MinecraftQuery();
        query.setHost(new InetSocketAddress(host, port));
        String data = query.fetchData();
        JSONObject json = new JSONObject(data);

        String favicon = json.getString("favicon");

        JSONObject jsonObject = new JSONObject();
        jsonObject.put("favicon", favicon);

        return jsonObject.toString();
    }

    @GetMapping(value = "/getDescription", produces = "application/json")
    public String getDescription(@Parameter(name = "host", description = "host of minecraft server", example = "134.255.208.230") String host, @Parameter(name = "port", description = "Server Port", example = "57200") int port) throws IOException {
        MinecraftQuery query = new MinecraftQuery();
        query.setHost(new InetSocketAddress(host, port));
        String data = query.fetchData();
        JSONObject json = new JSONObject(data);

        return json.getJSONObject("description").toString();
    }




//    @GetMapping(value = "/{host}/all", produces = "application/json")
//    public String ipAll(@Parameter(name = "host", description = "host of minecraft server", example = "5.75.236.165") @PathVariable String host, @Parameter(name = "port", description = "Server Port", example = "25565") int port) throws IOException {
//        return (ServerListPinger.queryServer(host, port));
//    }

//    @GetMapping("/products/{id}")
//    public ResponseEntity<Product> getProduct(@PathVariable("id") @Parameter(name = "id", description = "Product id", example = "1") Long id) {
//        //retrieval logic
//        return ResponseEntity.ok(new Product(1, "Product 1", "$21.99"));
//    }

}
