package com.brulijam.minecraftapi.controller;

import com.brulijam.minecraftapi.service.TelegramService;
import com.brulijam.minecraftapi.telegrambot.TelegramBot;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping("/telegramBot")
@Tag(name= "TelegramBot Controller")
@RequiredArgsConstructor
public class TelegramBotController {

    private final TelegramService telegramService;
    private final TelegramBot telegramBot;

    @Operation(summary = "sends a message debug")
    @PostMapping(value = "/debugSendMessage/{userId}", produces = "application/json")
    public void debugSendMessage(@PathVariable(name = "userId") long userId,
                            @Parameter(name = "message", description = "message to send", example = "Some Message :)") @RequestBody String message) {
        log.info("{}", userId);
        telegramBot.sendMessage(userId, message);
    }

    @Operation(summary = "sends a message")
    @PostMapping(value = "/sendMessage/{userId}", produces = "application/json")
    public void sendMessage(@PathVariable(name = "userId") long userId,
                            @Parameter(name = "message", description = "message to send", example = "Some Message :)") @RequestBody String message,
                            @Parameter(name = "accessToken", description = "Required token for sending messages to this user", example = "abcde12345") @RequestParam String accessToken) {
        log.info("{}", userId);
        if (accessToken.equals(telegramService.getTokenByUserId(userId))) {
            telegramBot.sendMessage(userId, message);
        }
    }



    @Operation(summary = "For debugging")
    @PostMapping(value = "/admin", produces = "application/json")
    public String admin() {
        return telegramService.getTelegramUsers().toString();
    }


}
