package com.brulijam.minecraftapi.controller;

import com.brulijam.minecraftapi.model.Tutel;
import com.brulijam.minecraftapi.service.TutelService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/tutel")
@Tag(name= "Tutel Controller")
@RequiredArgsConstructor
public class TutelController {

    private final TutelService tutelService;

    @GetMapping(value = "/getAll", produces = "application/json")
    public List<Tutel> getAll() {
        return tutelService.getTutelList();
    }

    @GetMapping(value = "/getByLabel", produces = "application/json")
    public Tutel getTutelByLabel(@Parameter(name = "label", description = "label of the turtle", example = "Turtle-1234") String label) {
        return tutelService.getByLabel(label);
    }

    @Operation(summary = "adds a tutel")
    @PostMapping(value = "/add")
    public Tutel addTutel(@Parameter(name = "label", description = "label of the tutel") @RequestParam String label,
                          @Parameter(name = "telegramUserId", description = "Telegram ID of the user the Turtle belongs to") @RequestParam long telegramUserId) {
        Tutel tutel =  new Tutel(label, telegramUserId);
        tutelService.addToList(tutel);
        return tutel;
    }

    @Operation(summary = "removes a tutel")
    @DeleteMapping(value = "/remove")
    public void removeTutel(@Parameter(name = "id", description = "id of the tutel") @RequestBody long id) {
        tutelService.removeById(id);
    }


}
