package com.brulijam.minecraftapi.service;

import com.brulijam.minecraftapi.model.Tutel;
import com.brulijam.minecraftapi.telegrambot.TelegramBot;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.json.JSONArray;
import org.json.JSONObject;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

@Getter
@RequiredArgsConstructor
@Component
public class TutelService {

    private final List<Tutel> tutelList = new ArrayList<>();
    private final TelegramBot telegramBot; // cycle :(

    public void addToList(Tutel tutel) {
        if (!tutelList.contains(tutel)) {
            tutelList.add(tutel);
            telegramBot.sendMessage(tutel.getTelegramUserId(), tutel.getLabel().replace("-", "\\-"));
        }
    }

    public void removeById(long id) {
        Tutel tutel = tutelList.stream()
                .filter(turtle -> turtle.getId() == id)
                .findFirst()
                .orElse(null);
        tutelList.remove(tutel);
    }

    public Tutel getById(long id) {
        return tutelList.stream()
                .filter(tutel -> tutel.getId() == id)
                .findFirst()
                .orElse(null);
    }

    public Tutel getByLabel(String label) {
        return tutelList.stream()
                .filter(tutel -> tutel.getLabel().equals(label))
                .findFirst()
                .orElse(null);
    }

    public List<Tutel> getTutelsForTelegramUser(long telegramUserId) {
        return tutelList.stream()
                .filter(Tutel -> Tutel.getTelegramUserId() == telegramUserId)
                .toList();
    }


    public JSONObject tutelToJson(Tutel tutel) {
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("id", tutel.getId());
        jsonObject.put("label", tutel.getLabel());
        jsonObject.put("telegramUserId", tutel.getTelegramUserId());
        jsonObject.put("fuelLevel", tutel.getFuelLevel());
        jsonObject.put("inventory", tutel.getInventory());
        return jsonObject;
    }

    public JSONArray tutelsToJson(List<Tutel> tutels) {
        JSONArray jsonArray = new JSONArray();

        for (Tutel tutel : tutels) {
            jsonArray.put(tutelToJson(tutel));
        }

        return jsonArray;
    }
}
