package com.brulijam.minecraftapi.telegrambot;

import com.brulijam.minecraftapi.model.Tutel;
import com.brulijam.minecraftapi.service.TelegramService;
import com.brulijam.minecraftapi.service.TutelService;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.telegram.telegrambots.bots.TelegramLongPollingBot;
import org.telegram.telegrambots.meta.api.methods.send.SendMessage;
import org.telegram.telegrambots.meta.api.objects.Message;
import org.telegram.telegrambots.meta.api.objects.Update;
import org.telegram.telegrambots.meta.api.objects.User;
import org.telegram.telegrambots.meta.exceptions.TelegramApiException;

import java.util.List;

/*
Commands
help - Displays help
listtutels - Lists all registered Tutels
gettutel - Get Tutel by label
stoptutel - Stop Tutel by label
listchests - Get all placed Chests
getchest - Get Chest by ID
*/

@Component
@RequiredArgsConstructor
@Getter
public class TelegramBot extends TelegramLongPollingBot {

    private final TutelService tutelService;
    private final TelegramService telegramService;
    private final TelegramFormatter telegramFormatter;

    @Value("${bot.name}")
    private String botUsername;
    @Value("${bot.token}")
    private String botToken;

    @Override
    public void onUpdateReceived(Update update) {

        if (update.hasMessage() && update.getMessage().hasText()) {
            User fromUser = update.getMessage().getFrom();

            String receivedMessage = update.getMessage().getText();


            handleMessage(fromUser, receivedMessage);


        }
    }

    private void handleMessage(User fromUser, String receivedMessage) {
        Long userId = fromUser.getId();

        if (receivedMessage.equals("/start")) {
            if (!(telegramService.getAccessTokens().containsKey(userId))) {
                telegramService.addUserToList(fromUser);
            }
            String accessToken = telegramService.getTokenByUserId(userId);
            sendMessage(userId, "Your Telegram UserID is `" + userId + "` and your accessToken is ||" + accessToken + "||");

        } else if (receivedMessage.equals("/help")) {
            sendMessage(userId, "/start \\- Description\n/help -\\ This help\n/list_tutels \\- Description\n/get_tutel_by_label \\- Description\n/placeholder \\- Description\n/placeholder \\- Description\n");

        } else if (receivedMessage.equals("/listtutels")) {
            List<Tutel> tutels = tutelService.getTutelsForTelegramUser(userId);
            tutels.forEach(tutel -> sendMessage(userId, telegramFormatter.formatTutel(tutel)));

//            sendMessage(userId,  tutelService.tutelsToJson(tutels).toString());

        } else if (receivedMessage.startsWith("/gettutel ")) {
            String label = receivedMessage.substring(receivedMessage.indexOf(" ")+1);
            System.out.println(label);
            Tutel tutel = tutelService.getTutelList().stream()
                    .filter(Tutel -> Tutel.getLabel().equals(label))
                    .findFirst()
                    .orElse(null);
            if (tutel != null) {
                sendMessage(userId, telegramFormatter.formatTutel(tutel));
            } else {
                sendMessage(userId, "Tutel not found");
            }
        } else {
            sendMessage(userId, "I have no Idea what you want lol");
        }
    }

    @Override
    public String getBotUsername() {
        return botUsername;
    }

    @Override
    public String getBotToken() {
        return botToken;
    }

    public void sendMessage(Long chatId, String messageToSend) {
        SendMessage sendMessage = SendMessage.builder()
        .chatId(chatId.toString())
        .parseMode("MarkdownV2")
        .text(messageToSend)
        .build();

        try {
            execute(sendMessage);
        } catch (TelegramApiException e) {
            e.printStackTrace();
        }
    }
}
